"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@commerce-apps/core");
class Client extends core_1.BaseClient {
    constructor(config) {
        super(config);
        if (!!!config.baseUri) {
            config.baseUri = "";
        }
        this.authSchemes["ShopperJWT"] = new core_1.AuthSchemes["ShopperJWT"]();
        this.authSchemes["OAuth2_0"] = new core_1.AuthSchemes["OAuth2_0"]();
        this.authSchemes["OAuth2_0"] = new core_1.AuthSchemes["OAuth2_0"]();
    }
    /**
    * Allows access to multiple products by a single request. This convenience resource should be used instead making separated requests, saving bandwidth and CPU time on the server. The URI is the same as requesting a single Product by ID, but multiple IDs wrapped by parentheses and separated are provided. If a parenthesis, or the separator, is part of the identifier itself, it has to be URL encoded. Instead of a single Product document, a result object of Product documents is returned. Note: Only products that are online and assigned to a site catalog are returned. The maximum number of IDs is 24. If none of the products requested are found, the cache-control header defaults to 60 seconds.
    */
    getProducts(parameters) {
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = {
            "siteId": parameters["siteId"],
            "ids": parameters["ids"],
            "expand": parameters["expand"],
            "inventoryIds": parameters["inventoryIds"],
            "currency": parameters["currency"],
            "locale": parameters["locale"],
            "allImages": parameters["allImages"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/products",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * To access a single products resource, you construct a URL with an ID (typically a SKU) for a product. In response, the server returns a corresponding product
document, provided the product is online and assigned to a site catalog. The document contains variation attributes
(including values) and the variant matrix. This data is provided for both the master and the variant.
    */
    getProductByID(parameters) {
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "id": parameters["id"]
        };
        const queryParameters = {
            "siteId": parameters["siteId"],
            "expand": parameters["expand"],
            "inventoryIds": parameters["inventoryIds"],
            "currency": parameters["currency"],
            "locale": parameters["locale"],
            "allImages": parameters["allImages"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/products/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * When you use the URL template, the server returns multiple categories (a result object of category documents). You can use this template as a convenient way of obtaining multiple categories in a single request, instead of issuing separate requests for each category. You can specify up to 50 multiple IDs. You must enclose the list of IDs in parentheses. If a category identifier contains parenthesis or the separator sign, you must URL encode the character. The server only returns online categories.
    */
    getCategories(parameters) {
        const pathParameters = {
            "organizationId": parameters["organizationId"]
        };
        const queryParameters = {
            "siteId": parameters["siteId"],
            "ids": parameters["ids"],
            "levels": parameters["levels"],
            "locale": parameters["locale"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/categories",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * When you use the URL template below, the server returns a category identified by its ID; by default, the server
also returns the first level of subcategories, but you can specify another level by setting the levels
parameter. The server only returns online categories.
    */
    getCategoryByID(parameters) {
        const pathParameters = {
            "organizationId": parameters["organizationId"],
            "id": parameters["id"]
        };
        const queryParameters = {
            "siteId": parameters["siteId"],
            "levels": parameters["levels"],
            "locale": parameters["locale"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/organizations/{organizationId}/categories/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.ShopperJWT
        });
    }
    /**
    * Action to get the list of catalog IDs with no filtering.
    */
    getCatalogs(parameters) {
        const pathParameters = {};
        const queryParameters = {
            "select": parameters["select"],
            "expand": parameters["expand"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/catalogs",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Gets the catalog with the specified information.
    */
    getCatalog(parameters) {
        const pathParameters = {
            "catalogId": parameters["catalogId"]
        };
        const queryParameters = {
            "select": parameters["select"],
            "expand": parameters["expand"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/catalogs/{catalogId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Updates the catalog with the specified information.
    */
    updateCatalog(parameters, body) {
        const pathParameters = {
            "catalogId": parameters["catalogId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/catalogs/{catalogId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to get all the categories with no filtering.
    */
    getCategoriesFromCatalog(parameters) {
        const pathParameters = {
            "catalogId": parameters["catalogId"]
        };
        const queryParameters = {
            "select": parameters["select"],
            "expand": parameters["expand"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/catalogs/{catalogId}/categories",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Deletes the category by catalog ID and category ID.
    */
    deleteCategoryFromCatalog(parameters) {
        const pathParameters = {
            "catalogId": parameters["catalogId"],
            "categoryId": parameters["categoryId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/catalogs/{catalogId}/categories/{categoryId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to read an existing category within a catalog. By default, the server
also returns the first level of sub-categories, but you can specify another level by setting the levels
parameter. Using a large value for levels may cause performance
issues in case of a large and deep category tree.
    */
    getCategoryFromCatalog(parameters) {
        const pathParameters = {
            "catalogId": parameters["catalogId"],
            "categoryId": parameters["categoryId"]
        };
        const queryParameters = {
            "levels": parameters["levels"],
            "expand": parameters["expand"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/catalogs/{catalogId}/categories/{categoryId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Updates a catalog category using the information provided.
    */
    updateCategoryInCatalog(parameters, body) {
        const pathParameters = {
            "catalogId": parameters["catalogId"],
            "categoryId": parameters["categoryId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/catalogs/{catalogId}/categories/{categoryId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Creates a catalog category using the information provided.
    */
    createCategoryInCatalog(parameters, body) {
        const pathParameters = {
            "catalogId": parameters["catalogId"],
            "categoryId": parameters["categoryId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/catalogs/{catalogId}/categories/{categoryId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Searches for category product assignments.

The query attribute specifies a complex query that can be used to narrow down the search. This is the list
of searchable attributes:

product_id - String
product_name - String
online_flag - Boolean
searchable - Boolean
valid_from - DateTime
valid_to - DateTime
creation_date - DateTime


Sortable Fields:

product_id - String
product_name - String
position - Double
creation_date - DateTime


Expansions that can be applied for the search request:

product_base - String - This expand will enable retrieval of the following basic Product information:
product_images - String - to fetch preview image and image groups specified for the given product
product_all_images - String - to fetch preview image and image groups specified for the product plus images for its variants and variation groups
product_variations - String to fetch variations related information, version 17.8+
product_availability - String to fetch availability related information, version 17.8+
product_categories - String to fetch category related information, version 17.8+
product_prices - String to fetch prices related information, version 17.8+
product_options - String to fetch options related information, version 17.8+
product_all - String to fetch all expanded information, version 17.8+

  
      brand
      ean
    link
  long_description
    manufacturer_name
    manufacturer_sku
      name
    page_description
    page_keywords
    page_title
    searchable
  short_description
    type
    unit
      upc
  

    */
    searchProductsAssignedToCategory(parameters, body) {
        const pathParameters = {
            "catalogId": parameters["catalogId"],
            "categoryId": parameters["categoryId"]
        };
        const queryParameters = {
            "siteId": parameters["siteId"]
        };
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/catalogs/{catalogId}/categories/{categoryId}/category-product-assignment-search",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Retrieves a category product assignment.


For example, if we have products A, B, C at positions 1, 2, 7.5, and delete assignment for product B,
the products end up A, B, C at positions 1, null, 7.5.
    */
    getAssignedProductFromCategory(parameters) {
        const pathParameters = {
            "catalogId": parameters["catalogId"],
            "categoryId": parameters["categoryId"],
            "productId": parameters["productId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/catalogs/{catalogId}/categories/{categoryId}/products/{productId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Removes a category product assignment.


For example, if we have products A, B, C at positions 1, 2, 7.5 and delete assignment for product B,
the products end up A, B, C at positions 1, null, 7.5.
    */
    unassignProductFromCategory(parameters) {
        const pathParameters = {
            "catalogId": parameters["catalogId"],
            "categoryId": parameters["categoryId"],
            "productId": parameters["productId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/catalogs/{catalogId}/categories/{categoryId}/products/{productId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Updates the category product assignment with the specified information, such as position.
As the assigned position n is a normalized target position, we&#x27;ll make sure that the product is assigned
to a position so that the order of positions are maintained.

For example, if we have products A, B, C, D at positions 1, 2, 3, 4 and update product A with a  new position of 3,
the end result is B, C, A, D with order of positions 1, 2, 3, 4. If we then update product C to no position,
the end result is B, A, D, C with order of positions 1, 2, 3, null.

If there are n existing positioned assignments, updating product to position &gt;&#x3D; n will end with a new assignment with a position such that the order of positions is maintained.
    */
    updateProductCategoryAssignment(parameters, body) {
        const pathParameters = {
            "catalogId": parameters["catalogId"],
            "categoryId": parameters["categoryId"],
            "productId": parameters["productId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/catalogs/{catalogId}/categories/{categoryId}/products/{productId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Creates a category product assignment using the information provided.

As the assigned position n is a normalized target position, we&#x27;ll make sure that the product is assigned
to a position so that the order of positions are maintained.

For example, if we have products A, B, C at positions 1, 2, 3, and product D is assigned to
position 2, the end result is A, D, B, C with order of positions 1, 2, 3, 4.

If there are n existing positioned assignment, assigning a new product to position &gt;&#x3D; n+1 will end
with the new assignment with position n+1.
    */
    assignProductToCategory(parameters, body) {
        const pathParameters = {
            "catalogId": parameters["catalogId"],
            "categoryId": parameters["categoryId"],
            "productId": parameters["productId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/catalogs/{catalogId}/categories/{categoryId}/products/{productId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Searches for catalog categories in the scope of catalog.
By default, the server also returns the first level of subcategories,
but you can specify another level by setting the levels parameter.
Using a large value for levels may cause performance
issues with a large and deep category tree.

The query attribute specifies a complex query that can be used to narrow down the search. These are the list searchable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
parent_category_id - String


The output of the query can also be sorted. These are the the sortable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
position - Double

    */
    searchCategoriesInCatalog(parameters, body) {
        const pathParameters = {
            "catalogId": parameters["catalogId"]
        };
        const queryParameters = {
            "levels": parameters["levels"]
        };
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/catalogs/{catalogId}/category-search",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Searches for catalogs.

The query attribute specifies a complex query that can be used to narrow down the search. These are the  searchable attributes:

id - String
name - String
description - String
creation_date - DateTime


There are two additional fields that can be used as search filters. They are not attributes in CatalogWO object,
but can be used as filters to query catalogs based on site assignments.

is_master_catalog - Boolean
is_storefront_catalog - Boolean


On using is_master_catalog in the search query, catalogs without any site assignments are returned.
On using is_storefront_catalog in the search query, catalogs with one or more site assignments are returned.

The output of the query can also be sorted. These are the sortable attributes:

id - String
name - String
description - String
creation_date - DateTime

    */
    searchCatalogs(parameters, body) {
        const pathParameters = {};
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/catalog-search",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Searches for catalog categories anywhere they appear.
By default, the server also returns the first level of subcategories,
but you can specify another level by setting the levels parameter.
Please note, using a large value for levels may cause performance
issues with a large and deep category tree.

The query attribute specifies a complex query that can be used to narrow down the search. These are the searchable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
catalog_id - String


The output of the query can also be sorted. These are the sortable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
position - Double

    */
    searchCategories(parameters, body) {
        const pathParameters = {};
        const queryParameters = {
            "levels": parameters["levels"]
        };
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/category-search",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Deletes the product by ID.
    */
    deleteProduct(parameters) {
        const pathParameters = {
            "productId": parameters["productId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/products/{productId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to get product information.
    */
    getProduct(parameters) {
        const pathParameters = {
            "productId": parameters["productId"]
        };
        const queryParameters = {
            "siteId": parameters["siteId"],
            "expand": parameters["expand"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/products/{productId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Update a product using the information provided.

Fields that can be updated:
name, page_description, long_descripton, page_title,
page_keywords, brand, ean,upc, manufacture_sku,
manufacture_name, searchable, unit, searchable,
online_flag, default_variant_id.
    */
    updateProduct(parameters, body) {
        const pathParameters = {
            "productId": parameters["productId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/products/{productId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Creates a product using the information provided. If a product with the same unique identifier exists, it will be cleaned and overwritten unless the header x-dw-validate-existing&#x3D;true is passed in with the request.
    */
    createProduct(parameters, body) {
        const pathParameters = {
            "productId": parameters["productId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/products/{productId}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Searches product variations for master product or variation group product.

The query attribute specifies a complex query that can be used to narrow down the search. This is the list
of searchable attributes:

id - String
product_id - String
name - String
online - SiteSpecific Boolean
in_stock - Boolean
searchable - SiteSpecific Boolean
ats - Actual available quantity to sell - Double
variation_attribute.ATTRIBUTE_ID (Ex:variation_attribute.color) - String

Sortable Fields:

id - String
product_id - String
name - String
online - SiteSpecific Boolean
in_stock - Boolean
searchable - SiteSpecific Boolean
ats - Actual available quantity to sell - Double


Note:
The calculated value of &quot;online&quot; and &quot;searchable&quot; is used in the search/sort.
A search/sort by the the site specific attributes require the Site ID query parameter to be set.
They are &quot;online&quot;, &quot;in_stock&quot;, &quot;searchable&quot; and &quot;ats&quot;.
We assume that every field that starts with variation_attribute. is searchable and dot is followed by ATTRIBUTE_ID&quot;.


The list of expansions to retrieve product information. The expand values available are:
        
          _base - Basic product information is retrieved. This expand is included by default.
          all - All product information including the following properties are retrieved:
          
              image
              price - siteId has to be provided to see this property
              price_currency - siteId has to be provided to see this property
          
          availability - Information related to the availability of the product variation.  This expand is not included by default.
          
              ats - siteId has to be provided to see this property
              in_stock - siteId has to be provided to see this property
              online - siteId has to be provided to see this property
              searchable
          
        variations - Information related to product variation is retrieved. This expand is included by default.
          attributes - Information related to product variation attributes is retrieved. This expand is not included by default.
        
    */
    searchProductVariations(parameters, body) {
        const pathParameters = {
            "productId": parameters["productId"]
        };
        const queryParameters = {
            "siteId": parameters["siteId"]
        };
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/products/{productId}/variant-search",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Reads variation groups for a product master.
    */
    getVariationGroupsForMasterProduct(parameters) {
        const pathParameters = {
            "masterProductId": parameters["masterProductId"]
        };
        const queryParameters = {
            "siteId": parameters["siteId"],
            "select": parameters["select"],
            "expand": parameters["expand"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/products/{masterProductId}/variation-groups",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Unassign a variation group product from a product master. The variation group product is not
deleted: it remains as a normal product after unsassign.
    */
    deleteVariationGroupForMaster(parameters) {
        const pathParameters = {
            "masterProductId": parameters["masterProductId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/products/{masterProductId}/variation-groups/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Read a variation group for a product master.
    */
    getVariationGroupForMasterProduct(parameters) {
        const pathParameters = {
            "masterProductId": parameters["masterProductId"],
            "id": parameters["id"]
        };
        const queryParameters = {
            "siteId": parameters["siteId"],
            "expand": parameters["expand"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/products/{masterProductId}/variation-groups/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Update a variation group for a product master.
    */
    updateVariationGroupInMasterProduct(parameters, body) {
        const pathParameters = {
            "masterProductId": parameters["masterProductId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/products/{masterProductId}/variation-groups/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Assign a variation group for a product master. If the variation group product does not initially exist,
one is created using the body passed in.
    */
    assignVariationGroupForMasterProduct(parameters, body) {
        const pathParameters = {
            "masterProductId": parameters["masterProductId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/products/{masterProductId}/variation-groups/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Reads variation for a product master.
    */
    getVariationsForMasterProduct(parameters) {
        const pathParameters = {
            "masterProductId": parameters["masterProductId"]
        };
        const queryParameters = {
            "siteId": parameters["siteId"],
            "select": parameters["select"],
            "expand": parameters["expand"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/products/{masterProductId}/variations",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Unassign a variation product from a product master.  The variation product is not deleted: it remains as a
normal product after unsassign.
    */
    deleteVariationForMaster(parameters) {
        const pathParameters = {
            "masterProductId": parameters["masterProductId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/products/{masterProductId}/variations/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Read a variation for a product master.
    */
    getVariationForMasterProduct(parameters) {
        const pathParameters = {
            "masterProductId": parameters["masterProductId"],
            "id": parameters["id"]
        };
        const queryParameters = {
            "siteId": parameters["siteId"],
            "expand": parameters["expand"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/products/{masterProductId}/variations/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Update a variation for a product master.
    */
    updateVariationsInMasterProduct(parameters, body) {
        const pathParameters = {
            "masterProductId": parameters["masterProductId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/products/{masterProductId}/variations/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Assign a variation for a product master.  If the variation product does not initially exist,
one is created using the body passed in.
    */
    createVariationForMasterProduct(parameters, body) {
        const pathParameters = {
            "masterProductId": parameters["masterProductId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/products/{masterProductId}/variations/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Read local and shared product options of a product.
    */
    getProductOptions(parameters) {
        const pathParameters = {
            "productId": parameters["productId"]
        };
        const queryParameters = {
            "select": parameters["select"],
            "currency": parameters["currency"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/products/{productId}/product-options",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Deletes a local product option or unbinds a shared product option from the product.
    */
    deleteProductOption(parameters) {
        const pathParameters = {
            "productId": parameters["productId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/products/{productId}/product-options/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Read a local or shared product option of a product.
    */
    getProductOption(parameters) {
        const pathParameters = {
            "productId": parameters["productId"],
            "id": parameters["id"]
        };
        const queryParameters = {
            "currency": parameters["currency"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/products/{productId}/product-options/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Updates a local product option with the information provided.
    */
    updateProductOption(parameters, body) {
        const pathParameters = {
            "productId": parameters["productId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/products/{productId}/product-options/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Creates a local product option using the information provided or binds a shared product option to the product.
    */
    createProductOption(parameters, body) {
        const pathParameters = {
            "productId": parameters["productId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/products/{productId}/product-options/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Deletes a local product option value by ID.
    */
    deleteProductOptionValue(parameters) {
        const pathParameters = {
            "id": parameters["id"],
            "optionId": parameters["optionId"],
            "productId": parameters["productId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/products/{productId}/product-options/{optionId}/values/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Read a local product option value of a local product option in a product.
    */
    getProductOptionValue(parameters) {
        const pathParameters = {
            "id": parameters["id"],
            "optionId": parameters["optionId"],
            "productId": parameters["productId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/products/{productId}/product-options/{optionId}/values/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Updates a local product option value with the information provided.
    */
    updateProductOptionValue(parameters, body) {
        const pathParameters = {
            "id": parameters["id"],
            "optionId": parameters["optionId"],
            "productId": parameters["productId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/products/{productId}/product-options/{optionId}/values/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Creates a local product option value using the information provided.
    */
    createProductOptionValue(parameters, body) {
        const pathParameters = {
            "id": parameters["id"],
            "optionId": parameters["optionId"],
            "productId": parameters["productId"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/products/{productId}/product-options/{optionId}/values/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to get product variation attribute value information.
    */
    getVariationAttributeValue(parameters) {
        const pathParameters = {
            "productId": parameters["productId"],
            "attributeId": parameters["attributeId"],
            "id": parameters["id"]
        };
        const queryParameters = {
            "siteId": parameters["siteId"],
            "expand": parameters["expand"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/products/{productId}/variation-attributes/{attributeId}/values/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Deletes the variation attribute value of a variation attribute bound to a master product.
    */
    deleteVariationAttributeValue(parameters) {
        const pathParameters = {
            "productId": parameters["productId"],
            "attributeId": parameters["attributeId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/products/{productId}/variation-attributes/{attributeId}/values/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Updates the variation attribute value of a variation attribute of a master product.
    */
    updateVariationAttributeValue(parameters, body) {
        const pathParameters = {
            "productId": parameters["productId"],
            "attributeId": parameters["attributeId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/products/{productId}/variation-attributes/{attributeId}/values/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Action to create a product variation attribute value.
    */
    createVariationAttributeValue(parameters, body) {
        const pathParameters = {
            "productId": parameters["productId"],
            "attributeId": parameters["attributeId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/products/{productId}/variation-attributes/{attributeId}/values/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Reads variation attributes of a product of type variant, variation master, or variation group.
    */
    getVariationAttributes(parameters) {
        const pathParameters = {
            "productId": parameters["productId"]
        };
        const queryParameters = {
            "select": parameters["select"]
        };
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/products/{productId}/variation-attributes",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers
        });
    }
    /**
    * Action to get variation attribute information only for master product.
    */
    getVariationAttribute(parameters) {
        const pathParameters = {
            "productId": parameters["productId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.get({
            client: this,
            path: "/products/{productId}/variation-attributes/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Deletes the variation attribute by ID.
    */
    deleteVariationAttribute(parameters) {
        const pathParameters = {
            "productId": parameters["productId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.delete({
            client: this,
            path: "/products/{productId}/variation-attributes/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Updates the variation attribute with the specified information.


name
slicing

    */
    updateVariationAttribute(parameters, body) {
        const pathParameters = {
            "productId": parameters["productId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.patch({
            client: this,
            path: "/products/{productId}/variation-attributes/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Creates a variation attribute using the information provided.
    */
    createVariationAttribute(parameters, body) {
        const pathParameters = {
            "productId": parameters["productId"],
            "id": parameters["id"]
        };
        const queryParameters = {};
        // @ts-ignore
        return core_1.StaticClient.put({
            client: this,
            path: "/products/{productId}/variation-attributes/{id}",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
    /**
    * Searches for products.

The query attribute specifies a complex query that can be used to narrow down the search. Attributes are grouped
into different buckets.  These are the list of searchable attributes with their corresponding buckets:

Main:

  id - String
  name - String
  online - SiteSpecific Boolean
  searchable - SiteSpecific Boolean
  valid_from - SiteSpefic DateTime
  valid_to - SiteSpecfic DateTime
  type - ProductType
  creation_date - DateTime

Catalog:

  catalog_id - String

Category:

  category_id - String

Special:

  type - {&quot;item&quot;, &quot;set, &quot;bundle&quot;, &quot;master&quot;, &quot;part_of_product_set&quot;, &quot;bundled&quot;, &quot;variant&quot;, &quot;variation_group&quot;, &quot;option&quot;, &quot;retail_set&quot;, &quot;part_of_retail_set&quot;}


The sortable properties are:

id - String
name - String
creation_date - DateTime


Note that catalog_id is the id of the catalog to which products are assigned to.

Only attributes in the same bucket can be joined using a disjunction (OR).
For instance, when joining id and catalog_id above, only a conjunction is allowed (AND), whereas id
and searchable can be joined using a disjunction because they are in the same bucket.  If an attribute
is used in a disjunction (OR) that violates this rule, an exception will be thrown.

The product search retrieves additional properties of the product when expansions are used.
  The available expand attribute values are:

          &#x27;all&#x27; will retrieve all the product properties.
        &#x27;availability&#x27; will retrieve the following properties:
          ats
          in_stock
          online
          
        &#x27;categories&#x27; will retrieve the following properties:
          assigned_categories
          
        &#x27;images&#x27; will retrieve the following properties:
          image
          
          &#x27;all_images&#x27; used with images will retrieve the following properties:
          image
          image_groups
          
        &#x27;prices&#x27; will retrieve the following properties:
          price
          price_currency
          
        &#x27;sets&#x27; will retrieve the following properties:
          set_products
          product_sets
          
        &#x27;bundles&#x27; will retrieve the following properties:
          product_bundles
          bundled_products
          
          


    */
    searchProducts(parameters, body) {
        const pathParameters = {};
        const queryParameters = {
            "siteId": parameters["siteId"]
        };
        // @ts-ignore
        return core_1.StaticClient.post({
            client: this,
            path: "/product-search",
            pathParameters: pathParameters,
            queryParameters: queryParameters,
            headers: (parameters || {}).headers, body: body, authScheme: this.authSchemes.OAuth2_0
        });
    }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=Product.js.map